Sendspin Party
Description: Experience multi-room audio with Sendspin - perfectly synchronized audio streaming across all your devices using the open Sendspin protocol.

Synchronization --.- ms

## Experience Multi-Room Audio

Open on other devices to hear perfectly synchronized audio across all of them.

Cast to Speaker
Copied!

## About Sendspin

Listen, control and see your music with Sendspin, the open audio protocol by the Open Home Foundation. Learn more about Sendspin.

Want to take control of music in your house and play on any speaker that you own? Check out Music Assistant, open-source and free.